StdioStepper class

Provides a command line interface for stepping through or skipping WebDriver commands.

Constructors

StdioStepper({LineReader? reader})

Properties

enabled ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
step(String method, String command, Object? params) → Future<bool>
Returns true if command should be executed, false if it should not be executed.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited