captureScreenshotAsList method
Take a screenshot of the current page as PNG as list of uint8.
Implementation
Uint8List captureScreenshotAsList() {
final base64Encoded = captureScreenshotAsBase64();
return base64.decode(base64Encoded);
}
Take a screenshot of the current page as PNG as list of uint8.
Uint8List captureScreenshotAsList() {
final base64Encoded = captureScreenshotAsBase64();
return base64.decode(base64Encoded);
}