WebDriverCommandEvent class

Constructors

WebDriverCommandEvent({String? method, String? endPoint, dynamic params, DateTime? startTime, DateTime? endTime, dynamic exception, dynamic result, StackTrace? stackTrace})

Properties

endPoint → String?
final
endTime → DateTime?
final
exception → dynamic
final
hashCode → int
The hash code for this object.
no setterinherited
method → String?
final
params → dynamic
final
result → dynamic
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stackTrace → StackTrace?
final
startTime → DateTime?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited